const ZeedhiAPIConstructor = require('zeedhi-functional-test-api');
const z = new ZeedhiAPIConstructor(browser, protractor);
const Helper = require('teknisa-helper');
const geral = new Helper.geral();
const loginPage = new Helper.login();
const parametrosPage = require('../../page-objects/pedidos/parametrosDePedidos.po.js');
const j = require('../../json/leitorJson.po.js');

describe('Tela Parâmetros De Pedidos', () => {
	const numeroDiasUteis = Helper.util.geraInt(99, 999);
	const diasValidade = Helper.util.geraInt(1, 999);
	const exclusaoPedido = 'Permite a Exclusão do Pedido';
	const numeroMaximoItens = Helper.util.geraInt(1, 999);
	const alteracaoPermitidaMenos = Helper.util.geraInt(1, 100);
	const alteracaoPermitidaMais = Helper.util.geraInt(1, 100);
	const valorMinimoPedidos = Helper.util.geraInt(999, 999999);
	const consultaProduto = 'Mostra o estoque apenas da filial do pedido';
	beforeEach(() => {
		browser.get('http://erpteste.teknisa.com/login/');
		loginPage.login(j.getValor('login'), j.getValor('senha'));
		parametrosPage.abrir();
		geral.searchAndClickGridField('NMFILIAL', j.getValor('unidade'), 'NMFILIAL');
	});

	afterEach(() => {
		geral.sair();
	});

	it('Deve acessar a tela Parâmetros De Pedidos', () => {
		expect(z.component.header.getTitle()).toBe('Parâmetros de Pedidos');
	});

	it('Deve Editar a aba Lançamento do Pedido', () => {
		parametrosPage.editarNacimentoNovoPedido(j.getValor('statusLancamento'), j.getValor('cliente'),
			j.getValor('cliente'), j.getValor('modalidadePadrao'), j.getValor('vendedor'), numeroDiasUteis);
		parametrosPage.editarLancamentoPedido('Não', 'Lançamento de Proposta', 'Sim', diasValidade, 'Sim', 'Não',
			'NF Venda', 'Sim', 'Sim', exclusaoPedido);
		geral.clickOk();
		geral.waitFieldVisibility('NMFANTCLIE');

		expect(geral.getTextoPorId('NMFANTCLIE'))
			.toBe(j.getValor('cliente'));
		expect(geral.getTextoPorId('NRDIASENTPED'))
			.toBe(numeroDiasUteis);
		expect(geral.getTextoPorId('IDEXCLPEDIDO'))
			.toBe(exclusaoPedido);
	});

	it('Deve editar Lançamento do Item', () => {
		geral.trocarAba('Lançamento do Item');
		parametrosPage.editarLancamentoItem('Não', numeroMaximoItens, j.getValor('descontoMaximo'),
			j.getValor('composicaoProduto'), 'Não', 'Sim', 'Não', j.getValor('grupoAutorizacao'));
		geral.clickOk();
		geral.waitFieldVisibility('DSGRUPOPER');

		expect(geral.getTextoPorId('DSGRUPOPER'))
			.toBe(j.getValor('grupoAutorizacao'));
		expect(geral.getTextoPorId('NRMAXITNFPED'))
			.toMatch(numeroMaximoItens);
	});

	it('Deve editar Estoque do Item', () => {
		geral.trocarAba('Estoque do Item');
		parametrosPage.editarEstoqueDoItem('Sim', 'Sim', 'Não', 'Não');
		geral.clickOk();
		geral.waitFieldVisibility('IDTESTAEST');

		// Testa Estoque
		expect(geral.getTextoPorId('IDTESTAEST'))
			.toBe('Sim');
		// Evoluir Estoque
		expect(geral.getTextoPorId('IDEVOLESTLIQMAN'))
			.toBe('Não');
	});

	it('Deve editar Preço do Produto', () => {
		geral.trocarAba('Preço do Produto');
		parametrosPage.editarPrecoDoProduto('Tabela de Preço', 'Sim', alteracaoPermitidaMenos,
			alteracaoPermitidaMais, j.getValor('grupoAutorizacao'));
		geral.clickOk();
		geral.waitFieldVisibility('DSPERALTMENOR');

		expect(geral.getTextoPorId('DSPERALTMENOR'))
			.toMatch(alteracaoPermitidaMenos);
		expect(geral.getTextoPorId('DSPERALTMAIOR'))
			.toMatch(alteracaoPermitidaMais);
		expect(geral.getTextoPorId('DSGRUALTPRECO'))
			.toBe(j.getValor('grupoAutorizacao'));
	});

	it('Deve editar Informações Financeiras', () => {
		geral.trocarAba('Informações Financeiras');
		parametrosPage.editarInformacoesFinanceiras(j.getValor('pendenciaFinanceira'),
			diasValidade, 'Não', j.getValor('situacaoFinanceira'), Helper.util.geraInt(999, 9999999),
			'Não', j.getValor('grupoAutorizacao'));
		geral.clickOk();
		geral.waitFieldVisibility('IDPENDFINAN');

		expect(geral.getTextoPorId('IDPENDFINAN'))
			.toBe(j.getValor('pendenciaFinanceira'));
		expect(geral.getTextoPorId('DSGROPERAPRO'))
			.toBe(j.getValor('grupoAutorizacao'));
	});

	it('Deve editar Dados de Comissão', () => {
		geral.trocarAba('Dados de Comissão');
		parametrosPage.editarDadosComissao(j.getValor('origemComissao'), 'Não', 'Sim');
		geral.clickOk();
		geral.waitFieldVisibility('IDCTRLVENEXP');

		expect(geral.getTextoPorId('IDCTRLVENEXP'))
			.toEqual(j.getValor('origemComissao'));
	});

	it('Deve editar Operações com Impostos', () => {
		geral.trocarAba('Operações com Impostos');
		parametrosPage.editarOperacoesComImpostos('Sim', 'Sim');
		geral.clickOk();
		geral.waitFieldVisibility('IDEXIBIMPITPED');

		expect(geral.getTextoPorId('IDEXIBIMPITPED'))
			.toEqual('Sim');
	});

	it('Deve editar Acesso', () => {
		geral.trocarAba('Acesso');
		parametrosPage.editarAcesso('Apenas do operador logado', j.getValor('grupoAutorizacao'),
			'Sim', j.getValor('mensagemVendedor'), consultaProduto, valorMinimoPedidos);
		geral.clickOk();
		geral.waitFieldVisibility('IDEXIBPEDIDO');

		expect(geral.getTextoPorId('IDEXIBPEDIDO'))
			.toEqual(j.getValor('pedidos'));
		expect(geral.getTextoPorId('VRMINPEDIDO'))
			.toMatch(Helper.util.formataReal(valorMinimoPedidos));
	});
});
